# Data Compatibility

Explore the `earthstat.data_compatibility` module designed to ensure and enhance compatibility across different data sets and formats used in geospatial analysis.

## Ensuring Data Compatibility

### Checking Data Compatibility
:::earthstat.data_compatibility.data_compatibility

## Resolving Compatibility Issues

### Addressing and Fixing Data Compatibility Issues
:::earthstat.data_compatibility.process_comp_issues
